@@ -11,7 +11,7 @@ from .fields import MeFields
 
 
 class MeQuery(MeFields, Query):
-    """MeQuery class
+    """| MeQuery class
 
     Creates a me query instance. "Me" being the authenticated user.
     The instance will be passed to the run_query method in order to execute the query.
@@ -36,8 +36,21 @@ class MeQuery(MeFields, Query):
         self.query.select(*self.fields(self.ds))
         return self
 
-    def select_accounts(self, account_query=None):
-        """Selects users accounts."""
-        account_connection_nodes = self.ds.AccountConnection.nodes.select(*AccountFields.fields(self.ds))
-        self.query.select(self.ds.User.accounts.select(account_connection_nodes))
+    def select_accounts(self, first=100, last=None, after=None, before=None):
+        """Selects users accounts.
+
+        :param first: Number of records to fetch from start
+        :type first: int
+        :param last: Number of records to fetch from end
+        :type last: int
+        :param after: Fetch after cursor
+        :type after: str
+        :param before: Fetch before cursor
+        :type before: str
+        """
+        accounts = self.ds.User.accounts.args(first=first, last=last, after=after, before=before)
+        account_nodes = self.ds.AccountConnection.nodes.select(*AccountFields.fields(self.ds))
+        pagination = self.ds.AccountConnection.pageInfo.select(*self.page_fields())
+
+        self.query.select(accounts.select(account_nodes).select(pagination))
         return self
